"""Parser for Xiaomi BLE advertisements.

This file is shamlessly copied from the following repository:
https://github.com/Ernst79/bleparser/blob/c42ae922e1abed2720c7fac993777e1bd59c0c93/package/bleparser/Xiaomi.py

MIT License applies.
"""
from __future__ import annotations

from .parser import XiaomiBluetoothDeviceData

__version__ = "0.0.1"

__all__ = ["XiaomiBluetoothDeviceData"]
